==> apache-inlong-1.12.0-src.tar.gz: apache-inlong-1.12.0/inlong-agent/agent-common/src/main/java/org/apache/inlong/agent/pojo/OracleTask.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.inlong.agent.pojo;

import lombok.Data;

@Data
public class OracleTask {

    private String hostname;
    private String user;
    private String password;
    private String port;
    private String serverName;
    private String dbname;

    private OracleTask.Snapshot snapshot;
    private OracleTask.Offset offset;
    private OracleTask.History history;

    @Data
    public static class Offset {

        private String intervalMs;
        private String filename;
        private String specificOffsetFile;
        private String specificOffsetPos;
    }

    @Data
    public static class Snapshot {

        private String mode;
    }

    @Data
    public static class History {

        private String filename;
    }

    @Data
    public static class OracleTaskConfig {

        private String hostname;
        private String user;
        private String password;
        private String port;
        private String dbname;
        private String serverName;

        private String snapshotMode;
        private String intervalMs;
        private String offsetFilename;
        private String historyFilename;

        private String specificOffsetFile;
        private String specificOffsetPos;
    }
}

==> apache-inlong-2.3.0-src.tar.gz: apache-inlong-2.3.0/inlong-agent/agent-common/src/main/java/org/apache/inlong/agent/pojo/OracleTask.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.inlong.agent.pojo;

import lombok.Data;

@Data
public class OracleTask {

    private String hostname;
    private String user;
    private String password;
    private String port;
    private String serverName;
    private String dbname;
    private String tableIncludeList;
    private String schemaIncludeList;

    private OracleTask.Snapshot snapshot;
    private OracleTask.Offset offset;
    private OracleTask.History history;

    @Data
    public static class Offset {

        private String intervalMs;
        private String filename;
        private String specificOffsetFile;
        private String specificOffsetPos;
    }

    @Data
    public static class Snapshot {

        private String mode;
    }

    @Data
    public static class History {

        private String filename;
    }

    @Data
    public static class OracleTaskConfig {

        private String hostname;
        private String username;
        private String password;
        private String port;
        private String database;
        private String schemaName;
        private String tableName;
        private String primaryKey;

        private String scanStartupMode;
        private String intervalMs;
        private String offsetFilename;
        private String historyFilename;

        private String specificOffsetFile;
        private String specificOffsetPos;
    }
}
